<?php

/*******************************************************************************
 *  Copyright 2011 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at: http://aws.amazon.com/apache2.0
 *  This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 *  CONDITIONS OF ANY KIND, either express or implied. See the License for the
 *  specific language governing permissions and limitations under the License.
 * *****************************************************************************
 */

/**
 * 
 * OrderWithContractCharges class shows how you can set the contract charges for the whole Order. 
 * The Contract charges are Shipment charges and Promotions for the whole Order.
 *
 */
require_once('.config.inc.php');

//Enter the purchase contract ID here
$purchaseContractId= "<ADD PURCHASE CONTRACT ID HERE>";

//Create an Object of CreateOrder
$lib = new CheckoutByAmazon_Service_CBAPurchaseContract();

//Object to pass the list of items to setItems function for setting the items to be purchased
$itemList = new CheckoutByAmazon_Service_Model_ItemList();

//Create a new PurchaseItem
$itemObject = new CheckoutByAmazon_Service_Model_PurchaseItem();

//Call create Item or create Physical item to create each item.
//Input : createItem(MerchantItemID,Title,UnitPriceAmount)
$itemObject->createItem('Item1','Title1',1);

//Add all the item objects to ItemList.
$itemList->addItem($itemObject);

try
{
    //Call setItems to associate all the items purchased to Amazon purchase session. The parameters are Purchase Contract ID and Itemlist 
    //created in the previous step. 
    $setItemsStatus = $lib->setItems($purchaseContractId,$itemList);

    //Create a promotion object to add Order Level promotions
    $promotion = new CheckoutByAmazon_Service_Model_Promotion();
      
    //Create the promotion
    //The arguments are: PromotionID,Promtion Description and Discount Amount
    $promotion->createPromotion('Promotion1','PromoDesc',2);
      
    //Add the promotion to the promotion list. Currently only one promotion is suported per Order
    $promotionListObject = new CheckoutByAmazon_Service_Model_PromotionList();
    $promotionListObject->addPromotion($promotion);
      
    /*
     * If only Shipping is provided at the Order level, then Promotions 
     * at item level, if present, will be applicable.
     * 
     *Similarly, if only Promotions are specified at the Contract level, the 
     *Shipping at item level, if present, will be applicable.
     *
     *If Promotions are specified at both Contract and Item levels then Contract 
     * level promotions take precedence,irrespective of the order in which they were specified.
     */

    //Create a charges object to add contract charges for the whole Order
    $charges = new CheckoutByAmazon_Service_Model_ContractCharges();


    //Set Promotion at Order Level
    $charges->setContractPromotions($promotionListObject);

    //Set Shipping Charges at Order Level
    $charges->setContractShippingCharges(3);

    //Call setContractCharges to associate all the Chrages Oject to Amazon Order
    $setContractChargesStatus = $lib->setContractCharges($purchaseContractId,$charges);

    //Check whether the calls to setItems and setContractCharges where successful
    if((($setContractChargesStatus == 1) || is_null($setContractChargesStatus)) && ($setItemsStatus == 1))
    {
        //Complete the Amazon transaction by using the below call. Pass the 
        //purchaseContractID, Integrator ID and Integrator Name to complete the order.
        $orderIdList = $lib->completeOrder($purchaseContractId, "A136CGJE3412", "Test Cart Integrator");

        //Displays the orders generated
        if(!is_null($orderIdList))
        {
            echo("<br> Orders completed Successfully");
            foreach ($orderIdList as $orderId) 
            {
                 echo("<br> OrderId : ");
                echo($orderId);
            }
        }
    }
}
//Error with the request parameters passed by the merchant
catch (CheckoutByAmazon_Service_RequestException $rex)
{
    echo("Caught Request Exception: " . $rex->getMessage());
    echo("Response Status Code: " . $rex->getStatusCode());
    echo("Error Code: " . $rex->getErrorCode() );
    echo("Error Type: " . $rex->getErrorType() );
    echo("Request ID: " . $rex->getRequestId() . "\n");
    echo("XML: " . $rex->getXML() . "\n");

}

//Internal system error occured
catch (CheckoutByAmazon_Service_Exception $ex)
{
    echo("Caught Exception: " . $ex->getMessage());
    echo("Response Status Code: " . $ex->getStatusCode());
    echo("Error Code: " . $ex->getErrorCode() );
    echo("Error Type: " . $ex->getErrorType() );
    echo("Request ID: " . $ex->getRequestId() . "\n");
    echo("XML: " . $ex->getXML() . "\n");
}

?>

